betty.extension.nginx.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.nginx.config module

Integrate Betty with nginx.

class betty.extension.nginx.config.NginxConfiguration

  Bases: `Configuration`

  Provide configuration for the `betty.extension.nginx.Nginx` extension.

  __init__(*, www_directory_path: str | None = None, https: bool | None = None)
  dump() → bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | type[Void]

    Dump this instance to a portable format.

  property https: bool | None

    Whether the nginx server should use HTTPS.

    Returns:

      `True` to use HTTPS (and HTTP/2), `False` to use HTTP (and HTTP 1), `None` to let this behavior depend on whether the project’s URL uses HTTPS or not.

  load(dump: bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]) → None

    Load dumped configuration.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump contains invalid configuration.

  update(other: Self) → None

    Update this configuration with the values from `other`.

  property www_directory_path: str | None

    The nginx server’s public web root directory path.